@@ -1,17 +1,18 @@
 ## Copyright (C) 1999 Paul Kienzle <pkienzle@users.sf.net>
 ##
-## This program is free software; you can redistribute it and/or modify it under
-## the terms of the GNU General Public License as published by the Free Software
-## Foundation; either version 3 of the License, or (at your option) any later
-## version.
+## This program is free software: you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
-## This program is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-## details.
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+## GNU General Public License for more details.
 ##
-## You should have received a copy of the GNU General Public License along with
-## this program; if not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License
+## along with this program; see the file COPYING. If not, see
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {[@var{x}, @var{t}] =} impz (@var{b})
@@ -76,12 +77,16 @@ function [x_r, t_r] = impz(b, a = [1], n = [], fs = 1)
     n = n + length(b);
   elseif isempty(n)
     n = length(b);
+  elseif (! isscalar (n))
+    ## TODO: missing option of having N as a vector of values to
+    ##       compute the impulse response.
+    error ("impz: N must be empty or a scalar");
   endif
 
   if length(a) == 1
-    x = fftfilt(b/a, [1, zeros(1,n-1)]);
+    x = fftfilt(b/a, [1, zeros(1,n-1)]');
   else
-    x = filter(b, a, [1, zeros(1,n-1)]);
+    x = filter(b, a, [1, zeros(1,n-1)]');
   endif
   t = [0:n-1]/fs;
 
@@ -104,3 +109,11 @@ function [x_r, t_r] = impz(b, a = [1], n = [], fs = 1)
   endif
 
 endfunction
+
+%!assert (size (impz (1, [1 -1 0.9], 100)), [100 1])
+
+## Missing functionality
+%!xtest
+%! [h, t] = impz (1, [1 -1 0.9], 0:101);
+%! assert (size (h), [101 1])
+%! assert (t, 0:101)
